globvars <- c(".", "N", "V9",
              "all_date_start_equal", "all_years_equal",
              "date_end", "date_start", "domain", "downscale_realisation",
              "ensemble", "experiment", "file_fullpath",
              "fn", "gcm", "icell", "institute_rcm",
              "list_files", "patterns", "period", "timefreq",
              "total_simulation_years", "value", "variable", "x", "y",
              "..cols_not_print")

utils::globalVariables(globvars)
